# Documentation

### Methods
- [Alert](#alert)
- [Confirm](#confirm)
- [Active Confirm](#active-confirm)

## Alert

Throws an alert box.

### Usage

```javascript
$.alert([Object options]);
```
**options**  
type: Object  
An object literal defining options for the alert box (see table below for all available options).

```javascript
$('.myElement').alert(String event [, Object options]);
```

**event**  
type: String  
One or more space-separated event types such as "click", or "mouseover".

**options**  
type: Object  
An object literal defining options for the alert box (see table below for all available options).

### Options

Name | Type | Description | Default
--- | --- | --- | ---
style | String | Define a style for the alert box. Options are "heat", "tomato", "mustard" and "wasabi". | Box styled in shades of grey.
coverBackground | Boolean | Fill the window with a semi-transparent cover when alert is throw. | `false`
title | String | A title for the alert box. | Alert
message | String | A message to display under the title. |
acceptButton | String | Text to use for the accept button. | OK
onAccept | Function | A callback function to execute when the accept button is clicked. |

## Confirm

Throws a confirm box.

### Usage

```javascript
$.confirm([Object options]);
```
**options**  
type: Object  
An object literal defining options for the confirm box (see table below for all available options).

```javascript
$('.myElement').confirm(String event [, Object options]);
```

**event**  
type: String  
One or more space-separated event types such as "click", or "mouseover".

**options**  
type: Object  
An object literal defining options for the confirm box (see table below for all available options).

### Options

Name | Type | Description | Default
--- | --- | --- | ---
style | String | Define a style for the alert box. Options are "heat", "tomato", "mustard" and "wasabi". | Box styled in shades of grey.
coverBackground | Boolean | Fill the window with a semi-transparent cover when alert is throw. | `false`
title | String | A title for the confirm box. | Confirm
message | String | A message to display under the title. |
confirmButton | String | Text to use for the confirm button. | Confirm
cancelButton | String | Text to use for the cancel button. | Cancel
onConfirm | Function | A callback function to execute when the confirm button is clicked. |
onCancel | Function | A callback function to execute when the cancel button is clicked. |

## Active Confirm

Throws a confirm box with an input. The user must enter a string that matches a pre-defined value before they can confirm.

### Usage

```javascript
$.activeConfirm([Object options]);
```
**options**  
type: Object  
An object literal defining options for the confirm box (see table below for all available options).

```javascript
$('.myElement').activeConfirm(String event [, Object options]);
```

**event**  
type: String  
One or more space-separated event types such as "click", or "mouseover".

**options**  
type: Object  
An object literal defining options for the confirm box (see table below for all available options).

### Options

Name | Type | Description | Default
--- | --- | --- | ---
style | String | Define a style for the alert box. Options are "heat", "tomato", "mustard" and "wasabi". | Box styled in shades of grey.
coverBackground | Boolean | Fill the window with a semi-transparent cover when alert is throw. | `false`
title | String | A title for the confirm box. | Confirm
message | String | A message to display under the title. |
confirmText | String | A string of text that a user must enter before they can confirm (case sensitive). | CONFIRM
confirmButton | String | Text to use for the confirm button. | Confirm
cancelButton | String | Text to use for the cancel button. | Cancel
onConfirm | Function | A callback function to execute when the user successfully confirms. |
onCancel | Function | A callback function to execute when the cancel button is clicked. |